@@ -214,8 +214,7 @@ bool ThemeEditorMainWindow::loadTheme(const QString &directory)
 {
     if (!directory.isEmpty()) {
         const QString filename = directory + QDir::separator() + QLatin1String("theme.themerc");
-        QFile file(filename);
-        if (!file.exists()) {
+        if (!QFileInfo::exists(filename)) {
             KMessageBox::error(this, i18n("Directory does not contain a theme file. We cannot load theme."));
             return false;
         }
