@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@ class ThemeEditorWidget : public GrantleeThemeEditor::EditorWidget
 {
     Q_OBJECT
 public:
-    explicit ThemeEditorWidget(QWidget *parent = Q_NULLPTR);
+    explicit ThemeEditorWidget(QWidget *parent = nullptr);
     ~ThemeEditorWidget();
 
 public Q_SLOTS:
